//
// Read directory from CP/M .dsk file.
//
// This is a stripped down version of a program in development that will
// allow the user to extract files from a .dsk image file and write them
// to the host filesystem.
//
// 06/11/2005
//
/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef	_DSKDIR_H_
#define	_DSKDIR_H_

#define	VERSION		1
#define	REVISION		6

#define	FALSE			0
#define	TRUE			1
#define	bool			int
#define	byte			unsigned char

#define	ENTER			'\n'
#define	BS				0x7f

#define	MAX_DIRECTORY_ENTRIES	256
#define	MAX_SEARCH					1000
#define	MAX_LEN						256

#define	SYNC			0x4e						// sync bytes
#define	IAM			0xfe						// ID address mark
#define	DAM			0xfb						// data address mark
#define	ALTDAM		0xf8						// alternate data address mark (used by RS)
// Any byte of 0xf8 through 0xfb can be a data address mark.

#define	MAX_SPT		32								// maximum sectors per track
#define	MAX_TRACK	80								// maximum track count
#define	SECSIZE		1024							// bytes per sector
#define	TRKSIZE		(SECSIZE * MAX_SPT)			// bytes per track
#define	BFRSIZE		(TRKSIZE * MAX_TRACK)	// total disk space

// The typedefs below allow us to deal with disk images in which not all
// tracks are formatted the same. This is usually because the boot tracks
// are formatted with a different sector size, count, or interleave than
// the other tracks.
//

typedef struct sectorEntry {
	int	size;				// size of sector in bytes
	byte	*dataptr;		// pointer into the disk buffer for this sector
} SEC_ENTRY, *SEC_PTR;

typedef struct trackEntry {
	int		spt;				// sectors in this track
	int		xlt[MAX_SPT];	// interleave for this track
	SEC_PTR	side[2];			// sector entry pointers
} TRACK_ENTRY, *TRK_PTR;

typedef struct fcb {
	byte	user;
	char	fname[11];
	byte	extent;
	byte	s[2];
	byte	reccnt;
	byte	map[16];
} FCB;

typedef struct fcbentry {
	struct fcb			fcb;
	struct fcbentry	*next;
} FCBENTRY;

typedef struct dirEntry {
	char	fname[16];
	int	size;
	FCBENTRY	*fcb;
} DIRENTRY;

typedef struct fileEntry {
	char					*fname;
	struct fileEntry	*next;
} FILELIST;

#endif // _DSKDIR_H_

