//
// Standard MM disk drive formats.
// each entry in CP/M is 128 bytes.
//
/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include	<stdio.h>
#include	"formats.h"

// Naming convention:
// FORMAT mmxxyyzzt
// where xx = number of tracks,
//       yy = ss for single sided, ds for double sided,
//       zz = sd for single density, dd for double density,
//       t = disk type:
//           s for system, d for data,
//           se for extended system, de for extended data,
//           ss for super system, ds for super data.

FORMAT mm40ssdds = {
	{"Montezuma Micro Standard SYSTEM (40T, SS, DD, 170K)"},
	{				// dpb
		36,		// spt
		4,			// bsh
		15,		// blm
		1,			// exm
		84,		// dsm
		127,		// drm
		0xc0,		// al0
		0,			// al1
		32,		// cks
		2			// off
	},
	{				// dpb extensions
		18,		// physical spt
		1,			// sector size code
		40,		// max track
		0x80,		// option bits
		1,			// drive type code
		{0,0,0,0,0,0,0,0,0,0,0,0}	// filler
	},
	{				// interleave
		1,3,5,7,9,11,13,15,17,2,4,6,8,10,12,14,16,18,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40ssddd = {
	{"Montezuma Micro Standard DATA (40T, SS, DD, 200K)"},
	{	40,4,15,1,99,127,0xc0,0,32,0},
	{	10,2,40,0x80,2,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40dsdds = {
	{"Montezuma Micro Standard DS SYSTEM (40T, DS, DD, 350K)"},
	{	36,4,15,1,174,127,0xc0,0,32,2},
	{	18,1,40,0xc0,3,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,11,13,15,17,2,4,6,8,10,12,14,16,18,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40dsddd = {
	{"Montezuma Micro Standard DS DATA (40T, DS, DD, 400K)"},
	{	40,4,15,1,199,127,0xc0,0,32,0},
	{	10,2,40,0xc0,4,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80ssdds = {
	{"Montezuma Micro 80T SYSTEM (80T, SS, DD, 350K)"},
	{	36,4,15,1,174,127,0xc0,0,32,2},
	{	18,1,80,0x80,5,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,11,13,15,17,2,4,6,8,10,12,14,16,18,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80ssddd = {
	{"Montezuma Micro 80T DATA (80T, SS, DD, 400K)"},
	{	40,4,15,1,199,127,0xc0,0,32,0},
	{	10,2,80,0x80,6,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80dsdds = {
	{"Montezuma Micro 80T DS SYSTEM (80T, DS, DD, 710K)"},
	{	36,4,15,0,354,127,0xc0,0,32,2},
	{	18,1,80,0xc0,7,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,11,13,15,17,2,4,6,8,10,12,14,16,18,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80dsddd = {
	{"Montezuma Micro 80T DS DATA (80T, DS, DD, 800K)"},
	{	40,4,15,0,399,127,0xc0,0,32,0},
	{	10,2,80,0xc0,8,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40ssddse = {
	{"Montezuma Micro Extended SYSTEM (40T, SS, DD, 190K)"},
	{	40,4,15,1,94,127,0xc0,0,32,2},
	{	10,2,40,0x80,9,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40dsddse = {
	{"Montezuma Micro Extended DS SYSTEM (40T, DS, DD, 390K)"},
	{	40,4,15,1,194,127,0xc0,0,32,2},
	{	10,2,40,0xc0,10,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80ssddse = {
	{"Montezuma Micro Extended 80T SYSTEM (80T, SS, DD, 390K)"},
	{	40,4,15,1,194,127,0xc0,0,32,2},
	{	10,2,80,0x80,11,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80dsddse = {
	{"Montezuma Micro Extended 80T DS SYSTEM (80T, DS, DD, 790K)"},
	{	40,4,15,0,394,127,0xc0,0,32,2},
	{	10,2,80,0xc0,12,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,7,9,2,4,6,8,10,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40ssddds = {
	{"Montezuma Micro SUPER DATA (40T, SS, DD, 220K)"},
	{	44,4,15,1,109,127,0xc0,0,32,0},
	{	6,3,40,0x80,13,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,2,4,6,0,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm40dsddds = {
	{"Montezuma Micro SUPER DS DATA (40T, DS, DD, 440K)"},
	{	44,4,15,1,219,127,0xc0,0,32,0},
	{	6,3,40,0xc0,14,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,2,4,6,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80dssdds = {
	{"Montezuma Micro 80T SUPER DATA (80T, SS, DD, 440K)"},
	{	44,4,15,1,219,127,0xc0,0,32,0},
	{	6,3,80,0x80,15,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,2,4,6,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT mm80dsddds = {
	{"Montezuma Micro 80T SUPER DS DATA (80T, DS, DD, 880K)"},
	{	44,4,15,0,439,127,0xc0,0,32,0},
	{	6,3,80,0xc0,16,
		{0,0,0,0,0,0,0,0,0,0,0,0}
	},
	{	1,3,5,2,4,6,
		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	}
};

FORMAT *Formats[MAX_FORMAT] = {
	&mm40ssdds,
	&mm40ssddd,
	&mm40dsdds,
	&mm40dsddd,
	&mm80ssdds,
	&mm80ssddd,
	&mm80dsdds,
	&mm80dsddd,
	&mm40ssddse,
	&mm40dsddse,
	&mm80ssddse,
	&mm80dsddse,
	&mm40ssddds,
	&mm40dsddds,
	&mm80dssdds,
	&mm80dsddds,
	NULL
};

// end
