//
// Standard formats for Montezuma Micro CP/M v 2.32
//
/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef	_STDFMTS_H_
#define	_STDFMTS_H_

#ifndef byte
#define byte	unsigned char
#endif
#ifndef word
#define word	unsigned short
#endif

#define	MAX_FORMAT	256

/*
;
; Each DPB in Montezuma Micro CP/M contains extension
; bytes beyond those specified by CP/M.
;
; Extension bytes are:
; byte 0 = physical sectors/track
; byte 1 = sector size code:
;        0 = 128
;        1 = 256
;        2 = 512
;        3 = 1024
; Documentation implies that bytes 2 and 3 are the number of
; tracks, but actual data is a pointer to the dpb vector.
; byte 2,3 = pointer to dpb vector
; byte 4 = option bits:
;      bit 7 = 0 single density, 1 double density
;      bit 6 = 0 single sided, 1 double sided
;      bit 5 reserved
;      bit 4 = 0 normal data, 1 inverted data
;      bit 3 = 0 sector numbering same on both sides,
;              1 sector numbers on side 1 continue from side 0
;      bit 2 = 0 track number same on both sides,
;              1 track number increments on side change
;      bit 1 = 0 use both sides before changing tracks,
;              1 use all of side 0, then use side 1
;      bit 0 = 0 use side 1 starting at track 0 & go up,
;              1 use side 1 starting at last track & go down
; byte 5 = 0 for ram or hard disk, else is floppy
;              and number is the disk definition entry + 1.
*/

// Sector size codes:

#define	SS128		0	// 128 bytes per sector
#define	SS256		1	// 256 bytes per sector
#define	SS512		2	// 512 bytes per sector
#define	SS1024	3	// 1024 bytes per sector

typedef struct dpb {
	word	spt;			// sectors per track
	byte	bsh;			// block shift factor
	byte	blm;			// block mask
	byte	exm;			// extent mask
	word	dsm;			// total storage capacity
	word	drm;			// directory entries
	byte	al0;			// allocation vector 0
	byte	al1;			// allocation vector 1
	word	cks;			// directory check vector
	word	off;			// offset - number of reserved tracks
} DPB;

typedef struct dpbext {
	byte	pspt;			// physical sectors per track
	byte	sizecode;	// sector size code
	word	maxtrack;	// number of tracks
	byte	option;		// option bits
	byte	type;			// drive type code
	byte	rsrvd[30];	// filler
} DPBEXT;

typedef struct driveFormat {
	char		name[64];	// format name
	DPB		dpb;			// dpb
	DPBEXT	dpbext;		// dpb extensions
	byte		xlt[32];		// sector interleave
} FORMAT;

extern FORMAT	*Formats[MAX_FORMAT];

#endif	// _STDFMTS_H_

// end

